package com.muyu.common.cache.config;
/**
 * 抽象缓存层
 * @ClassName CacheAbsBasic
 * @Description CacheAbsBasic:类的描述
 * @Date 2024/9/30 1:39
 * @author MingWei.Zong
 */

import com.muyu.common.redis.service.RedisService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;


public abstract class CacheAbsBasic<K,V> implements CacheBasic<K,V> {

    @Autowired
    private RedisService redisService;

    @Override
    public void put(K key, V value) {
        redisService.setCacheObject(encode(key),value);
    }

    /**
     * 获取缓存中车辆的数据
     * @param key
     * @return
     */
    @Override
    public V getManage(K key) {
        return redisService.getCacheObject(encode(key));
    }

    /**
     * 将数据存入缓存
     * @param key
     * @param value
     */
    @Override
    public void putManage(K key, V value) {
        redisService.setCacheObject(encode(key),value);
    }


    /**
     * 获取缓存中故障的数据
     * @param key
     * @return
     */
    @Override
    public V getFault(K key) {
        return redisService.getCacheObject(encode(key));
    }

    /**
     * 将数据存入故障缓存
     * @param key
     * @param value
     */
    @Override
    public void putFault(K key, V value) {
        redisService.setCacheObject(encode(key),value);
    }


    @Override
    public V get(K key) {
        return redisService.getCacheObject(encode(key));
    }

    @Override
    public void remove(K key) {
        redisService.deleteObject(encode(key));
    }
}
