package com.muyu.event.process.basic;

import org.springframework.context.ApplicationListener;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @Author: zi run
 * @Date 2024/9/30 15:37
 * @Description 基础事件处理器
 */
@Component
public class BasicEventHandler<T> implements ApplicationListener<BasicEvent<T>> {

    /**
     * 具体事件监听器列表
     */
    private final List<BasicEventListener<T>> listeners;

    /**
     * 构造函数，用于注入具体事件监听器
     *
     * @param listeners 具体事件监听器列表
     */
    public BasicEventHandler(List<BasicEventListener<T>> listeners) {
        this.listeners = listeners;
    }

    /**
     * 处理应用事件
     *
     * @param event 事件对象
     */
    @Override
    public void onApplicationEvent(BasicEvent<T> event) {
        listeners.forEach(l -> l.onEvent(event));
    }
}