package com.muyu.event.process.consumer;

import com.muyu.event.process.util.CacheUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.annotation.Exchange;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.QueueBinding;
import org.springframework.amqp.rabbit.annotation.RabbitListener;

/**
 * @Author: zi run
 * @Date 2024/10/5 12:50
 * @Description 车辆下线消费者
 */
@Slf4j
@RequiredArgsConstructor
public class GoOfflineConsumer {

    /**
     * 缓存工具
     */
    private final CacheUtil<String> cacheUtil;

    /**
     * 处理车辆下线事件
     *
     * @param vin 车辆的识别码，用于从缓存中移除相应的数据
     */
    @RabbitListener(
            bindings = @QueueBinding(
                    value = @Queue(value = "GO_OFFLINE", durable = "true"),
                    exchange = @Exchange(value = "OFFLINE_EXCHANGE", type = "fanout")
            )
    )
    public void offline(String vin) {
        log.info("清除缓存，车辆vin: {}", vin);
        cacheUtil.remove(vin);
    }
}
